package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````C10``#0```!0@0````0`!30`(``'
M`"@`%@`5``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!@````8````!`````$````!````````````````````W&\`
M`-QO```%```````!``$```#,?0``S'T!`,Q]`0!P`@``G!(```8```````$`
M`@```-1]``#4?0$`U'T!`/````#P````!@````0```!1Y71D````````````
M```````````````&````$````%+E=&3,?0``S'T!`,Q]`0`T`@``-`(```0`
M```!````+VQI8B]L9"UM=7-L+6%R;6AF+G-O+C$`$0```$P````(````"```
M``&0$``E0`2`*(`0!:"&4(2``0``"R`$C3B`$D&*!`@(3````$T```!1````
M5@```%<```!>````7P```&``````````8@```&,`````````9````&4```!H
M```````````````!KS3H:G^:?.K3[P[.WD<M;\7?'R[%F[:XC?$.U&34?'94
M/)0A_^0.V7%8'/JA;&#"Y3\LL@&+;T+ZUX?B1\8!6.^7>;OCDGQ5PSS29Z_,
M9H@'<--#1=7L,V+;[16,)<Q_J9R;X*<""FH:GE"_VE<;H^#[20``````````
M````````````````#!`````````#``<```````"``0```````P`1``$`````
M`````````!(````)```````````````1````[`$`````````````$0```(@!
M`````````````!(````0```````````````2````Q0$`````````````$@``
M`!@``````````````!(````?```````````````2````^0$`````````````
M$@```-$!`````````````!(````H```````````````@````'P,`````````
M````(0```$```````````````!(```!&```````````````2````30``````
M````````$@```.P"`````````````!(```#=`@`````````````2````5```
M````````````$@```#8"`````````````!(```!;```````````````2````
MO`(`````````````$@```&(``````````````!(```!J```````````````2
M````I0(`````````````$@```'(``````````````!(```![````````````
M```@````U@(`````````````$@```)<``````````````!(```"<````````
M```````2````"@(`````````````$0```,,"`````````````!(```!C`@``
M```````````2````HP``````````````$@```%4"`````````````!(```!C
M`P`````````````2````'@,`````````````$0```(<"`````````````!(`
M```+`P`````````````2````%0(`````````````$@```"`#````````````
M`!$```"J```````````````2`````P,`````````````$@```+,`````````
M`````!$```"6`0`````````````2````Q0``````````````(@```-0`````
M`````````"````#J```````````````2````S@(`````````````$@```',"
M`````````````!(```#O```````````````2````]0``````````````(```
M`+`"`````````````!(````/`0`````````````2````M@$`````````````
M$@```!0!`````````````!(```"5`@`````````````2````&@$`````````
M````$@```*4!`````````````!(````H`0`````````````2````.0$`````
M````````$@```#$"`````````````!(```!"`@`````````````2````/P$`
M````````````$@```'P"`````````````!(```#\`@`````````````2````
M3@$`````````````$@```/0"`````````````!(```!B`0`````````````2
M````+`(`````````````$@```&D!`````````````!(```!P`0``````````
M```2````'0,`````````````(0```($!`````````````!(```!C!```:)`!
M```````0`!(`&`,```43``"(`0``$@`)`.8!``!-,````@```!(`"@"E`P``
M31\``-`$```2``D`<P0``+$E```X````$@`)`((#``#I&@``!````!(`"0`7
M!```#1````(````2``<`R`,``!TD``"4`0``$@`)`!T$```\@`$``````!``
M$@!+!```[1H``'`!```2``D```0``#R``0``````$``2`),#``#A'@``;```
M`!(`"0"R`P``C1D``$`````2``D`N@,``)$>``!`````$@`)`-X#``#1+@``
MP@```!(`"0#S`P``71P``!(````2``D`#`0``&B0`0``````$``2`&X$``!H
MD`$``````!``$@!(`P``J10``$`````2``D`*P0``&\<``":````$@`)`.D#
M```X@`$`!````!$`$0!$!```/(`!```````0`!$`!00``(T4````````$@`)
M`!0$``"5+@``/````!(`"0!1`P``T1X``!`````2``D`;`,``!4:``#4````
M$@`)`%@$``"3+P``N````!(`"0!B!```:)`!```````0`!(`-P0```D=``"(
M`0``$@`)``!O<&5N9&ER`'-T9&5R<@!R96%L;&]C`&%C8V5S<P!S;G!R:6YT
M9@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E:P!G971P:60`<W1R8VUP
M`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S=')N8VUP`&-L;W-E9&ER`%])5$U?
M9&5R96=I<W1E<E1-0VQO;F5486)L90!O<&5N`'-T<G-T<@!S=')C:'(`<F5A
M9&QI;FL`7U]S=&%C:U]C:&M?9W5A<F0`7U]C>&%?9FEN86QI>F4`7U]R96=I
M<W1E<E]F<F%M95]I;F9O`&5X:70`8VQO<V4`7TE435]R96=I<W1E<E1-0VQO
M;F5486)L90!R96%D`')M9&ER`%]?<W1A=%]T:6UE-C0`7U]E<G)N;U]L;V-A
M=&EO;@!M:V1I<@!?7VQS=&%T7W1I;64V-`!P=&AR96%D7V=E='-P96-I9FEC
M`&UE;6-P>0!S=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S
M>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?
M8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%]F
M:6YI`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`
M4&5R;%]C<F]A:U]M96UO<GE?=W)A<`!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y
M;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A
M;&QO8P!F<')I;G1F`'-T<F1U<`!P=&AR96%D7V%T9F]R:P!R96%D9&ER`'-P
M<FEN=&8`<W1R=&]K`'-T<FYC<'D`7U]L:6)C7W-T87)T7VUA:6X`7U]?96YV
M:7)O;@!L:6)P97)L+G-O`&QI8F,N;75S;"UA<FUV-RYS;RXQ`%]S=&%R=%]C
M`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C=7)R96YT7V5X96-?
M<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A<E]S971U<%]L:6)P871H`'!A<E]M
M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!
M4E]"3T]4`'-H85]U<&1A=&4`;7E?<&%R7W!L`'!A<E]B87-E;F%M90!?7V)S
M<U]S=&%R=`!?7V5N9%]?`'-H85]I;FET`%]?8G-S7W-T87)T7U\`<&%R7V1I
M<FYA;64`<&%R7VEN:71?96YV`%]E9&%T80!P87)?9FEN9'!R;V<`<VAA7V9I
M;F%L`%]?8G-S7V5N9%]?`%]E;F0`<&%R7V-L96%N=7``+W5S<B]L:6(O<&5R
M;#4O8V]R95]P97)L+T-/4D4`````S'T!`!<```#0?0$`%P```,!_`0`7````
MS'\!`!<```#8?P$`%P````"``0`7````"(`!`!<````,@`$`%P```!2``0`7
M````&(`!`!<````<@`$`%P```""``0`7````)(`!`!<````L@`$`%P```#"`
M`0`7````.(`!`!<```#$?P$`%00``,A_`0`5!0``T'\!`!4-``#4?P$`%1P`
M`-Q_`0`5(```X'\!`!4J``#D?P$`%2T``.A_`0`5+P``['\!`!4P``#P?P$`
M%34``/1_`0`5.@``^'\!`!4\``#\?P$`%4```-!^`0`6`P``U'X!`!8&``#8
M?@$`%@<``-Q^`0`6"```X'X!`!8)``#D?@$`%@H``.A^`0`6"P``['X!`!8,
M``#P?@$`%@T``/1^`0`6#P``^'X!`!80``#\?@$`%A$```!_`0`6$@``!'\!
M`!83```(?P$`%A0```Q_`0`6%0``$'\!`!86```4?P$`%A<``!A_`0`6&```
M''\!`!89```@?P$`%AH``"1_`0`6&P``*'\!`!8=```L?P$`%AX``#!_`0`6
M'P``-'\!`!8A```X?P$`%B(``#Q_`0`6(P``0'\!`!8D``!$?P$`%B4``$A_
M`0`6)P``3'\!`!8H``!0?P$`%BD``%1_`0`6*P``6'\!`!8L``!<?P$`%BX`
M`&!_`0`6+P``9'\!`!8P``!H?P$`%C$``&Q_`0`6,@``<'\!`!8S``!T?P$`
M%C0``'A_`0`6-@``?'\!`!8W``"`?P$`%C@``(1_`0`6.0``B'\!`!8[``",
M?P$`%CT``)!_`0`6/@``E'\!`!8_``"8?P$`%D$``)Q_`0`60@``H'\!`!9#
M``"D?P$`%D0``*A_`0`610``K'\!`!9&``"P?P$`%D<``+1_`0`62```N'\!
M`!9)``"\?P$`%DL```&UO>@!0'!'!.`MY03@G^4.X(_@"/"^Y:!N`0``QH_B
M%LJ,XJ#^O.4`QH_B%LJ,XIC^O.4`QH_B%LJ,XI#^O.4`QH_B%LJ,XHC^O.4`
MQH_B%LJ,XH#^O.4`QH_B%LJ,XGC^O.4`QH_B%LJ,XG#^O.4`QH_B%LJ,XFC^
MO.4`QH_B%LJ,XF#^O.4`QH_B%LJ,XEC^O.4`QH_B%LJ,XE#^O.4`QH_B%LJ,
MXDC^O.4`QH_B%LJ,XD#^O.4`QH_B%LJ,XCC^O.4`QH_B%LJ,XC#^O.4`QH_B
M%LJ,XBC^O.4`QH_B%LJ,XB#^O.4`QH_B%LJ,XAC^O.4`QH_B%LJ,XA#^O.4`
MQH_B%LJ,X@C^O.4`QH_B%LJ,X@#^O.4`QH_B%LJ,XOC]O.5X1_WG`,:/XA;*
MC.+L_;SE`,:/XA;*C.+D_;SE`,:/XA;*C.+<_;SE`,:/XA;*C.+4_;SE`,:/
MXA;*C.+,_;SE`,:/XA;*C.+$_;SE`,:/XA;*C.*\_;SE`,:/XA;*C.*T_;SE
M`,:/XA;*C.*L_;SE`,:/XA;*C.*D_;SE`,:/XA;*C.*<_;SE`,:/XA;*C.*4
M_;SE`,:/XA;*C.*,_;SE`,:/XA;*C.*$_;SE`,:/XA;*C.)\_;SE`,:/XA;*
MC.)T_;SE`,:/XA;*C.)L_;SE`,:/XA;*C.)D_;SE`,:/XA;*C.)<_;SE`,:/
MXA;*C.)4_;SE`,:/XA;*C.),_;SE`,:/XA;*C.)$_;SE`,:/XA;*C.(\_;SE
M`,:/XA;*C.(T_;SE`,:/XA;*C.(L_;SE`,:/XA;*C.(D_;SE`,:/XA;*C.(<
M_;SE>$?]YP#&C^(6RHSB$/V\Y0#&C^(6RHSB"/V\Y7A'_><`QH_B%LJ,XOS\
MO.4`QH_B%LJ,XO3\O.4`QH_B%LJ,XNS\O.4`QH_B%LJ,XN3\O.4`QH_B%LJ,
MXMS\O.4`QH_B%LJ,XM3\O.4`QH_B%LJ,XLS\O.4`QH_B%LJ,XL3\O.4`QH_B
M%LJ,XKS\O.5PM8BPS>D&$`62!JD%J@>H3$S_]USO3$M\1.-8`Y-+2P.:XU@1
M1AA&!)/_]\KN2$OC6!UX1TOD6'VY__<,[T9*>D308!"Y`2#_]U+O__=T[R!H
M__>L[X#X?5<@:/_WIN^0^,XS0_`"`X#XSC,@:/_WGN^0^,XS0_`!`X#XSC,'
MF,(<!#"P\8!/`=/_]P[O@``#DO_W1N\Q2P:<>T188"-H!YD#8"Y+`YI[1$-@
M+4L`\1`%>T0;:(-@*TM[1,-@`2.90CG<`"D!\0,#3^J#`T_P``'8OQ`C)4W!
M4`"1)$E]1`-&>43H:/_WENX$1ABYZ&C_]PKO!$8?37U$Z&C_]\CN'4AX1`#P
M&/E@N:MH([D;2'A$`/`1^:A@&4M[1)AH"+$!\,3X%TM[1-AH__=2[__W`.X@
M1@BP<+U4^"-@`3-%^`1KO>>D:P$`.`$``#0!```$`0``&`$``!!M`0"V;`$`
MY!\``'YL`0#5'P``<FP!`.,%``!8;`$`F1T``$`=```V;`$`*FP!`$_P``M/
M\``.`TEY1&A&(/`/#.5&`/`"^#II`0`?M0M+"TI[1)I8`I(*2II8`Y(`(@&2
M"4J;6`(=`),!:`*;`YC_]VCN!;!=^`3[`+\2:@$`%`$``/P````(`0``!D@'
M2P=*>$1[1(-">D0#T`5+TU@#L1A'<$<`OTIK`0!(:P$`S&D!`!`!```(2`E)
M>$1Y1`D:RP\'2@/KH0%)$'I$`]`%2]-8`[$81W!'`+\@:P$`'FL!`)AI`0`L
M`0``#DL0M7M$#DP;>'Q$H[D-2^-8([$,2WM$&&C_]SSN__>__PI+XU@;L0E(
M>$3_]XCM`2((2WM$&G`0O0"_[&H!`&YI`0`D`0``GFH!``P!``!B6@``O&H!
M``BU!TL'2GM$FU@KL09)!TAY1'A$__<8[KWH"$"JYP"_&FD!`"@!``",:@$`
M(EH``!A++>GP1WM$BD8%1CBS%DJ;6!QH!+,#1AY&$_@!*SJYH49V&\A&6?@$
M>R>Y/$83X#TJ]=#PYS)&*48X1O_W?NT`*._1NUT]*^S1J.L$!*00RO@`0'0<
M/$0@1KWH\(<$1OKG`+_J:`$`'`$```>U#4H-2WI$TUAI1AMH`9-/\``#__>^
M_PE*"$MZ1--8&F@!FUI`3_```P'0__=`[@.P7?@$^P"_?F@!`"`!``!H:`$`
M<[452A5+>D336`1&&V@!DT_P``-N1A)-?40Q1B!&__>7_UBY#TH-2WI$TU@:
M:`&;6D!/\``##=#_]QCN"DL`FNM8&V@#ZX(#6FA#^`0K`"KZT>+G`K!PO3IH
M`0`@`0``*&@!`!AH`0`<`0``+>GP1S-*-$MZ1--8J+`;:">33_```P5&P+$#
M>+.Q__>.[`9&D+$M3]_XM(#?^+20?T3X1/E$,$;_]\CL!$:(N3!&__?Z["A&
M__>([29*(DMZ1--8&F@GFUI`3_```S70__?.[1,T.48@1O_WJNP`*.'0048@
M1O_WI.P`*-O0*$;_][CM@D8@1O_WM.U01`(P__>Z[()&(T8J1DE&__>8[6E&
M4$;_]V#M`3!01@O0!)L#]'!#L_6`3P71__>A_U!&__=F[;?G__>:[/CG*+"]
MZ/"'`+_,9P$`(`$``.\9``#L&0``[1D``(1G`0`0M1=*%TMZ1*BPTUAI1@1&
M&V@GDT_P``/_]TKMV+D$FP/T<$.S]8!/`M"S]2!/!M$"(2!&__<D[+#Z@/!`
M"0I*"$MZ1--8&F@GFUI`3_```P/0__=@[0`@\><HL!"]`+_B9@$`(`$``*9F
M`0`MZ?!/#49*2DI+>D336(6P&V@#DT_P``,+>`9&/2L(OP$U*$;_]SKM`JD'
M1C!&__>M_M_X!)$$1OE$L+'_]R[MAT(SV`$\%?@!.P3X`3\`*_G1.DHW2WI$
MTU@::`.;6D!/\``#8=#_]R#M-4M9^`.@VO@`L%OX)#``*T/1,4L$\0((>T0:
M:$_JB`@`*CS004981O_WM.O*^````"C9T-KX`#"81``C2/@$/`*4,T881A/X
M`2L*L3TJ^=$A2X`;6?@#0`(W.$3=^`B0U/@`@/_W\.M(^"D``"B[T"-H`II3
M^"(@%O@!&Q-&$7`!,@FQ/2GWT3TB&G`5^`$K`_@!+P`J^=&FYP$TM><!(D!&
M&F#_]]#K`9``*)S064:H\0@"__?.ZP&;RO@`,+GG!;"]Z/"/<F8!`"`!``!$
M9@$`)F8!`!P!``".9P$`$[4*3`I+?$3C6!AH__>*[`A+"4GC6'E$`9,(2P&:
M>T0"L+WH$$#_]V^\`+\N90$`&`$``#`!``!Q%P``:U4``!.U#$L,2GM$G%@@
M:/_W:NS_]];_(&C_]V;L`"('2PA)>T3-Z0`R!TIY1'I$__<ZZP*P$+WN9`$`
M&`$``*,9```[%P``(PH``#"U+TDO2JWU`%V'L'E$BE@-]0!3%#,2:!I@3_``
M`O_W-NLI2@.L>D0`DBA*`T9!\@$!($9Z1/_W#.M#'`_1`",C2"!)>$0-]0!2
M05@4,@AH$6A(0$_P``$MT/_W/NRP]8!?`-G_W@WU@%40-2!&3_2`4BE&__>6
MZP0>X-M@'/_W,.L#1@`HVM"H0@+2`AF50NC3JT("V2H9DT+CTT'R`0*40M_<
M(D881BE&__<$[``B`T8"5<3G&$8-]0!=![`PO:!D`0`@`0``%A<``/P6``!H
M9`$`__>4ORWI\$\-1DY)K?6%74U*>42%L`1&3$B*6`WUA5-X1`PS$F@:8$_P
M``+_]Y+]+R$&1B!&__<HZYBQ1$@A1GA$__>+_D-)/TIY1`WUA5.*6`PS$6@:
M:%%`3_```FK0__?0ZR!&__?(ZSM)@T9Y1"A&__>DZP=&.$O?^.20W_CDH'M$
M^43Z1`.3`"_6T#IX`"H(OT]&5K$Y1C!&__>2ZBBY,4EY1/_WBNL'1NWG.$;_
M]Z+K`"4X1,$;$/@!+2\J&-`+\0$""D2R]8!?MMH#FPWQL`BH\00%`)-21CM&
M3_2`42A&`93_]TKJ`3"P]8!?`MG_W@5PW^<H1@2I__<VZZBY6/B0/`/T<$.S
M]0!/#M$!(2A&__<LZDBY%$@I1GA$__<<_BA&__>2Z@1&B^<020`@>42WYR!&
M#?6%706PO>CPCP"_QF,!`"`!``!,%@``-18``(YC`0`4%@```A8``)\5``#*
M%@``WA4``%<5``!0%0```T83^`$K`KEP1R\J"+\81O?G$+4$1@BQ`W@KN1](
M>$2]Z!!`__=6NO_W+.L!."!$A$(#1A[2&G@!."\J^-"<0AC2&D82^`$9+RD1
MT0$[G$(:1@/2$7@!.R\I^-`2&Y,<L_6`7QC8`3*R]8!?#=G_WA-&Y.><0NG1
M(W@O*P+1"$AX1,WG!TAX1,KG!TLA1GM$&$;_]VKJ$+T`(/SGD10``"\4``"*
M%```>F,!`#"U1TI'2WI$B[#36&I&1DD;:`F33_```WE$`?$*`P'Q*@051AAH
M66@(,P/%HT(J1O?1&X@]2"N`>$3_]YW\/$@\3'A$__>8_#M(?$1X1/_WD_PZ
M2'A$__>/_#E(>$3_]XO\.$AX1/_WA_PW2'A$__>#_#9(>$3_]W_\($;_]WS\
M,TAX1/_W>/PR2'A$__=T_#%(>$3_]T[\`480L2!&__=-_2Y(>$3_]T7\`488
ML2Q(>$3_]T/]*TAX1/_W._P!1JBQ*4AX1/_W.?TH22A(>41X1/_W,_TG2A)+
M>D336!IH"9M:0$_P``,8T/_W?.HB2'A$__<?_`%&$+$@2'A$XN<?20HB>40-
M\1$`__=\Z0`HV]$<2`WQ&P%X1-3G"[`PO;)A`0`@`0``]5$``"X4```M%```
M8Q0``"L4```L%```*Q0``#,4``#@$P``+Q0``#44``#+$P``+Q0``"X4```M
M$P``+!0``(@3``!"%```MQ,``-Y@`0`$%```IQ,```$4``"+$P``"+4+2WM$
M&V@!,PS1"4AX1/_WS/L@L0!X$+$P.!B_`2`%2WM$&&`%2WM$&&@(O0"_;&$!
M``T3``!.80$`2&$!``BU__<2ZO_W6.D`L0!H"+WWM19/!$9_1#A&__>G^R%&
M!48(L0-X*[D12'A$`["]Z/!`G^3_]R+IL+D@1O_WZ.D&1BA&__?DZ3!$`C#_
M]^KH!D8(2PA)(D9Y1`"5>T3_]\;I,48X1N'G`[#PO303```@$P``/A(``!`3
M```MZ?!/W_A`%-_X0"2M]0%-B;!Y1-_X.%2*6`WU`4-(K'U$$FC:84_P``(<
M,RH=I/%T`P7Q$`ZD\5P,!D8'RH/H!P"^Z`\`K.@/`)[H`P"D\6@#*#6,Z`,`
ME>@'`(/H!P#\2/U/>$3_]T/[?T0%1M"Q`WC#L?_WCO_X2?1*>40-]0%#BE@<
M,Q%H&FA10$_P``(!T/_WANDH1@WU`4T)L+WH\$__]Y^X__=M_P5&F+FD\6@(
M6/@$"Q"YZ4U]1`O@__<7^P`H]=`#>``K\M#_]XSH!48`*.W0*$;_]USI0``!
M,/_W8NB!1H!&W_AXHP$]^D05^`$O`"IFT:3Q7`A8^`1;A;$H1O_W]/H%1@`H
M]M`#>``K\]#_][K[`"COT"A&__=DZ`5&I/%T"D6Y6O@$B[CQ``]9T)CX`#``
M*TO1*$;_]RKI@D9(1O_W)NE01`#R!$I01O_W*NB`1L-+Q$E[1`"3PTLJ1GM$
M>43-^`20__<`Z4_TX'%`1O_WU.@!,#;1__?*Z`-H$2LQT+I*NTFX6`"3,FA#
M1@!H>43_]XSH`"6W2:I*>40-]0%#BE@<,Q%H&FA10$_P``)_]&RO*$8-]0%-
M";"]Z/"/0$911O_WTN@(\0((C>=`1O_W6?L`**700$;_]P+H!4:?YT5&I^=`
M1@2I__>DZ(%&2+&>2Z%)^%@R:$-&>40`:/_W5NC'YZ3UB'4K:0/T<$.S]8!/
M[=%4^/B\__?$Z(-%Y]$K:</S"`.S]>!_X=%01O[WN.\%1I%(>$3_]U;Z`"A_
MT3=H.$;_]Z+H`RB"1A[9C$D$.'E$.$3^]X#ON+FZ\00/!-"Z1!KX!3PO*P_1
M=FANL3!&__>,Z`,H"-F"200X>40P1/[W:N\`*`B_-T;_]U;^@D8`*$#PH(`!
M1CA&_O>F[P9&`"@`\)B`3_`""4_P_S-O\!$"S?@`D"<?_O="[P8B.48P1O_W
M"N@4^`0\`"M#T13X`SQ#*S_1%/@"/$$K.]$4^`$\0RLWT2-X2"LTT6-X12LQ
MT4_P_S-O\#D",$;-^`"0_O<>[RDB.48P1O[WYN]"1EU+74E[1,WI`'-<2WE$
M>T0H1O_W(.A`1O[W_N]92"E&>$3_]]SZ*$;_]R?^*N<W:/[W3N\!1CA&__<E
M_`=&`"A_]':O<^<`(P`B`),P1@`C_O?N[@#PZ_V!1D_T`$(Y1C!&_O>R[P(>
M*-PP1J3Q1`;^]Z#OI/$P!TE&,$8`\%;^N4;?^`"Q^T0X1EE&%O@!*PKQ`0K^
M]^#ONO$4#P?Q`@?RT0`C!/@(/#A+.$E[1,WI`),W2T)&>T1Y1*GG.49(1@#P
MT_W)YS-)-$AY1'A$__>&^O[WLNXQ2S))>T3-Z0`#,4M"1BA&>T1Y1/[WM.\N
M3"].+T]\1'Y$?T1/].!Q*$;^]X+O`3"&T?[W>.\#:!$K@='^]Y+N"?$!"0"0
M(T9"1C%&*$;-Z0&7_O>6[^7G8E\!`"`!``"48`$`I!$```I?`0#X7@$`)!(`
M`/<1``"7$0``A!$``+P0`````0``8A$``-)=`0`Q$0``FQ```"P1```%$0``
M)1$``&H0``#X#@``S@X``$4/``!]$```O@\``%`.``#H#@``>0X``$\0``"=
M#P``(`X``!(.``"=#P``,1```'"U54M52GM$G%@@:/[W0N\%1B!H_O<^[Y7X
M9#"`^&4P3TAX1/_W_/@@L0-X,2L!T4-X"['_]UK\(&C^]RSO24D#(P$B>43^
M]X#N!4:@L2!H_O<@[^MH1$H9:'I$_O>`[NMH&VB;:%L"!M4@:/[W$N_K:!EH
M_O<D[B!H_O<,[SM)`R,!(GE$_O=@[@5&Z+$X2'A$__?%^`9&0+$@:/[W^NXR
M1NMH&6C^]USN#N#_]Z3Z!D8@:):S_O?N[NMH,D89:/[W3NXP1O[WS.X@:/[W
MXNX%1B!H_O?>[B9)`2)Y1/[WJ.TE2@%&>D0H1O[W.NX@:/[WT.X`(X#X93`@
M2"!,>$3_]X[X?$2@8("Y8&C_]Q#]H&!8N1M(>$3^]Z+M_O>Z[AE+>T1::.MH
M$FB[YQ=,3_3@<7Q$H&C^]XSN$2@*T$,<`2L'V0-&86@12*)H"6AX1/[WANUP
MO0"_GEH!`!@!``!1#0``J@X``)8.``!Q#@``L0P``!L.```F#@``.@P``#1;
M`0#\#0``%EL!``9;`0#E#0``.+4$1O_W6_O_]U#[!4;_]V?\<+%LL2-X6[$&
M22A&>43^][SMA4($T2!&O>@X0/_WA;@XO7$,```MZ?!/_4K^2WI$T[#36`&J
M%$8;:%&33_```P#Q7`4`\1P#4_@$&PFZG4)$^`0;^-%`)!%&#6I+:P0R:T"-
M:`EH:T!+0$_J\W,!/--C\='I2=#I`.<!G0)I#430^`C`%43":,1HC.H""@KJ
M!PJ*Z@(*`IJ,ZK<("D0(Z@X((D0%Z_YEB.H,"%5$D$1/ZKX*`YJ*ZK<$+$`*
M1&)$A.JW!!1$!)H(Z_5HBNJU"POJ"`L*1(OJ"@L"Z[<"!.OX9)-$3^JX"`6:
MB.JU!B9`"D121(;JM0861`::"^OT:XCJM`H*Z@L*"D0"Z[4"BNH("@;K^V:2
M1$_JNPL'FHOJM`4U0`I$0D2%ZK0%%40(F@KK]FJ+ZK8(".H*"`I$`NNT`HCJ
M"P@%Z_IED$1/ZKH*"9J*ZK8)">H%"0I$6D2)ZK8)D40*F@CK]6B*ZK4+"^H(
M"PI$`NNV`HOJ"@L)Z_AIDT1/ZK@("YJ(ZK4$!.H)!`I$4D2$ZK4$%$0,F@OK
M^6N(ZKD*"NH+"@I$`NNU`HKJ"`H$Z_MDDD1/ZKL+#9J+ZKD%)4`*1$)$A>JY
M!15$#IH*Z_1JB^JT"`CJ"@@*1`+KN0*(Z@L(!>OZ99!$3^JZ"@^:BNJT!BY`
M"D1:1(;JM`861!":".OU:(KJM0L+Z@@+"D0"Z[0"B^H*"P;K^&:31$_JN`@1
MFHCJM00T0`I$4D2$ZK4$%$02F@OK]FN(ZK8*"NH+"@I$!.O[9`+KM0)/ZKL+
M$YV*Z@@*B^JV"9)$%)H)Z@0)#40*Z_1J140*1(OJM`B)ZK8)J40"Z[8&:$T5
MF@CJ"@B(Z@L(L$16&1::">OZ:2I$3^JZ"@CK^6A>1(KJM`L"Z[0$BNJY`H+J
M"`(41!>:B^H)"U$9&)I>1`;K^&8J1$_JN`@$Z_9D442(ZKD*`NNY"8CJM@)B
M0(KJ!@J11!F:440!Z_1A*D1/ZK0$D$2$ZK8"2D"01!J:">OQ:0+K!0L;F@OK
MM@N$ZK$&".OY:(;J"08J1$_JN0D41(GJL0*"Z@@"%$0<FK-$*D0+Z_AK`NNQ
M`8GJN`*"Z@L"$40=F@3K^V0"ZP4*'II/ZKL+*D0!Z_1ARD2+ZK@)`NNX"(OJ
MM`)*0(GJ!`F01!^:RD0*Z_%J5AE/ZK$!()I>1('JM`N+Z@H+7D0"ZP4+(9H(
MZ_IH"^NT"X'JN@0&Z_AFA.H(!"I$3^JX"!%$B.JZ`G)`$40BFJ-$*D0+Z_9K
M`NNZ"HCJM@*"Z@L"DD0CF@'K^V$"ZP4)))I/ZKL+*D0*Z_%JP42+ZK8(`NNV
M!HOJL0*"Z@H"B.H!"!9$)9K!1`GK^FE4&4_JN@HFFEQ$BNJQ"XOJ"0M<1`+K
M!0L(X`"_F7F"6J'KV6[06`$`(`$```;K^68+Z[$+BNJY`7%`BT0GF03K]F0I
M1$_JM@8HFHI$ANJY`0OK]&MA0"I$BD1/ZKL%`NNY"8;JM`(*Z_MJ@NH+`D7J
MM`B11`CJ"@@%ZK0"*9E(Z@((ZTH)Z_II$40Q1$7JN@:(1`;J"08%ZKH!#D,J
MF0CK^6@11$_JN0D!Z[0!2>JZ!`Y$!.H(!`GJN@$,0RN9!NOX9A%$*41)ZK@%
M#$0U0`GJN`$-0RR9!.OV9!%$3^JV!@'KN@%&ZK@+#40+Z@0+!NJX`4OJ`0LM
MF07K]&411$E$1NJT"8M$">H%"0;JM`%)Z@$)+ID+Z_5K$41/ZK4%`>NX`47J
MM`J)1`KJ"PH%ZK0!2NH!"B^9">O[:1%$,41%ZKL&BD0&Z@D&!>J[`0Y#,)D*
MZ_EJ$41/ZKD)`>NT`4GJNP@.1`CJ"@@)ZKL!2.H!"#&9!NOZ9A%$*41)ZKH%
MB$0U0`GJN@$-0S*9,YP11`CK]F@!Z[L!3^JV!D;JN@L-1!1$!>OX90;JN@%,
M1`OJ"`M&ZK@)2^H!"PGJ!0D&ZK@!2>H!"329HT0+Z_5K$41/ZK4%`>NZ`47J
MN`J)1`KJ"PH%ZK@!2NH!"C69">O[:1%$,40VGD7JNP2*1`3J"00%ZKL!%D0&
MZ[@&#$,*Z_EJ-$1/ZKD)-YY)ZKL(">J[`0CJ"@@61"Y$2.H!"+!$.)X$Z_ID
M2>JZ`0CK]&@)ZKH%(4`61$_JM`0I0P;KNP9$ZKH%,40%Z@@%!.JZ!C5#.9X!
MZ_AA%D1.1$3JN`DU1`GJ`0D$ZK@&2>H&"3J>!>OQ919$3^JQ`0;KN@9!ZK@*
ML40*Z@4*`>JX!DKJ!@H[G@GK]6D61#1$0>JU!E1$!NH)"@'JM09*Z@8*/)X$
MZ_ED,D0"Z[@(/9Y;2D_JN0D61#%$B>JU!F9`,40^GM!$%D0(Z_1H!NNU!8GJ
MM`:&Z@@&-40_G@'K^&$61$_JN`BQ1(CJM`9.0+%$0)X%Z_%E%D0&Z[0$B.JQ
M!FY`-$1!G@GK]6D61$_JM06P1(7JL0:&Z@D&L$1"G@3K^6061`;KL0&%ZKD&
M9D`Q1$.>".OT:!9$3^JT!#5$A.JY!H;J"`8U1$2>`>OX819$!NNY"83JN`9.
M0+%$19X%Z_%E%D1/ZK$!-$2!ZK@&;D`T1$:>">OU:19$!NNX"('JM0:&Z@D&
ML$1'G@3K^6061$_JN0DQ1(GJM09F0#%$2)X(Z_1H%D0&Z[4%B>JT!H;J"`8U
M1$F>`>OX819$3^JX"+%$B.JT!DY`L41*G@7K\6461`;KM`2(ZK$&;D`T1$N>
M">OU:19$3^JU!;!$A>JQ!H;J"0:P1$R>!.OY9!9$!NNQ`87JN09F0#%$39X(
MZ_1H%D1/ZK0$-40$X`"_W+P;C];!8LJ$ZKD&ANH(!C5$3IX!Z_AA%D0&Z[D)
MA.JX!@&K3D"Q1-/X.&'3^#PQ!>OQ919$3^JQ`1-$-$1S1('JN`8)Z_5I;D`#
MZ[@(@>JU`S1$@^H)`P3K^61#1`/K]&,#8`SKN0.#8,-H"TH#Z[4%`VD\1!E$
M"4MZ1$1@Q6`!8=-8&FA1FUI`3_```P'0_O<TZE.PO>CPCP"_5E`!`"`!```(
MM6`@_O<LZ0I*"TD"8`+QB#)"8`+Q*4*B]982HO:+8H)@HO&(,L)@`"+`Z002
M@F'"90B]`2-%9_#ATL,MZ?!!%D8%1D-IT@";&"B_@FE#822_`3*"88-I!?$<
M!P/K5G.#8<!M\+'`\4`$M$(X1*B_-$:(0@/2`QF90@#2_]Z(0@'K!`@!V4!%
M^-,B1O[WTNGK;2-$0"OK91?1*$;_]UK[048V&P7Q7`@_+A#<N4("V;L9F4+B
MT[E"`M*+&9]"W=,R1CA&_O>VZ>YEO>CP@;E"`=E!1=+3CT(!\4`#`=F?0LS3
M#$8Z1E3X!!N<0D+X!!OYT2A&__<N^T`^(4;4YRWI\$$!\1P'2VF.:0Q&@"&3
M^H/XP_/%`UH<."H%1C:Z^50'ZP(`0]T`(<+Q0`+^]X;H($;_]P_[."(`(3A&
M_O=^Z"!&Q.D5:/_W!?OC>"!&*W!CB&MP(V@;"JMP(VCK<.-Y*W'CB&MQ8V@;
M"JMQ8VCK<>-Z*W)CB6MRHV@;"JMRHVCK<N-[*W/CB6MSXV@;"JMSXVCK<^-\
M*W1CBFMT(VD;"JMT(VGK=+WH\$'^]QNY`"'"\3@"PN<`OP&UO>@!0'!'.@``
M`#T````*````/0````\````]````)````#T````R````/0````(````]````
M!0```#T````3````/0````T````]````#````#T````C````/0```!$````]
M````)@```#T````!````/0```!<````]````"````#T````)````/0``````
M````````+W1M<`!005)?5$U01$E2`%1%35!$25(`5$U0`%5315(`55-%4DY!
M344`+BX`)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R
M;F%L<SHZ4$%2.CI"3T]4`"]P<F]C+R5I+R5S`&5X90!005)?5$5-4`!005)?
M4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/
M`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%
M0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U0
M1$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!
M3CT`,0!,1%],24)205)97U!!5$@`4UE35$5-`"4P,G@`)7,E<R5S)7,`<&%R
M+0`E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*`"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I
M<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E
M<F%T:6]N*0H`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U
M)7,`)7,E<W1E;7`M)74M)74E<P`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D52
M4TE/3@`Q+C`U,@!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`E
M<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@
M9F%I;&5D("AE<G)N;STE:2D*`"UE`"TM`&5V86P@)V5X96,@+W5S<B]B:6XO
M<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N
M9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'
M24,L("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A
M8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I
M;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL
M93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?
M=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_
M(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M
M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY
M("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8
M)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3
M549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE
M(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W
M:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF
M(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q
M"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO
M<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F
M:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T
M<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L
M96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0[
M"B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["F5V86P@>PI?<&%R7VEN:71?
M96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF
M:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@
M.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R
M?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/
M(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N
M86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A
M7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@
M7T9(+"`G/#IR87<G+"`D<')O9VYA;64@;W(@;&%S=#L*;7D@)&)U9CL*;7D@
M)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q
M,#(T.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@)&-H=6YK7W-I>F4I
M('L*)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D;2`]("1S:7IE("4@
M)&-H=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D;3L*
M?2!E;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H=6YK7W-I>F4["GT*
M=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K(%]&2"P@)&UA9VEC7W!O
M<RP@,#L*<F5A9"!?1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"10
M05)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'
M24,I*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@)&D["FQA<W0["GT*)&UA9VEC
M7W!O<R`M/2`D8VAU;FM?<VEZ93L*?0IL87-T(&EF("1M86=I8U]P;W,@/"`P
M.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F
M+"`T.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D
M8G5F*2P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI
M<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@
M("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&
M24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q
M6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H
M("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD
M968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I
M/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD
M("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M
M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE
M;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@
M)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL
M96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@
M/0HD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R
M8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@
M)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO
M9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE
M.PIM>2`D:6YF;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5](&]R
M(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U
M;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL
M93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@
M9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D
M92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P
M*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?
M87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["F]P96X@;7D@
M)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@
M(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A
M<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL
M($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z
M.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U
M:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F
M:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M
M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE
M;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O
M.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T
M('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT
M96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]
M"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A
M8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI
M=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T
M(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@
M;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*
M;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L
M;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I
M9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G
M*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@
M0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A
M9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!
M24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@
M>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2![
M"F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T
M($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@
M)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]
M"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF
M("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG
M*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E
M;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD
M8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@
M/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII
M;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?
M*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?
M:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D
M<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG
M="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ
M1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@
M(B1P87(B73L*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE
M=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S
M+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^
M("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG
M="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P
M:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@
M=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E
M871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L
M"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\
M($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T
M(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E
M:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1D871A7W!O
M<RD@>PIR96%D(%]&2"P@)&QO861E<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL
M;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6
M>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO
M*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*9F]R96%C:"!M
M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y
M?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=
M+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B
M.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A
M9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@
M*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN
M="@D;&]A9&5R*3L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D[
M"G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.
M+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N
M9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O
M;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F
M;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN
M84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D
M;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C
M(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@
M;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE
M*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE
M;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\
M7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@
M)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ
M*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I
M;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER
M+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S
M=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF
M("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D
M9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M0
M86-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M
M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*
M)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@
M=6YD968["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;
M0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1F:#X["F-L
M;W-E("1F:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E
M;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E
M<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L
M("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T
M:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII
M<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@
M;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*3L*;W5T<RAQ<5M7<FET=&5N
M(&%S("(D;F%M92)=*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F
M:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L
M(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A
M="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D[
M"F]P96X@;7D@)&9H+"`B/#IR87<B+"`D;W5T.PHD8W1X+3YA9&1F:6QE*"1F
M:"D["F-L;W-E("1F:#L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0[
M"GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?
M;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A
M8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L
M96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*)&9H
M+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL
M97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U
M:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E
M<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*
M)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E
M;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M
M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@
M87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3
M:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B10
M05(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.
M5GM005)?1$5"54=].PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6
M>U!!4E]414U0?2)=*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@
M(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE
M;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$
M:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE
M.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH
M/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N
M9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA
M;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H
M)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?
M;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@
M>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L
M<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S
M*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B
M72D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*
M8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]
M"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE
M(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=
M(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M
M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6
M*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I
M(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI
M.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T
M:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R
M"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E
M($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0[
M"G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&
M8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,[
M"G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/
M.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z
M.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ
M4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E
M(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R
M:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@
M5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@
M>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q
M=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER
M92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E
M<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN
M960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI
M+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A
M=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-
M4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN
M97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@
M)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED
M*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE
M9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ
M3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA
M;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!
M345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^
M(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM
M?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]
M("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@;7D@)&9H+"`B/#IR87<B
M+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z
M("0A73L*<V5E:R`D9F@L("TQ."P@,CL*;7D@)&)U9CL*<F5A9"`D9F@L("1B
M=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X
M+"`R.PIR96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21B=68B.PI]"F5L<V4@
M>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI32$$["FUY
M("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@(CPZ
M<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA
M;64B.B`D(5T["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T
M>"T^:&5X9&EG97-T.PI]('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF
M:6=[7V1E;&EM?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS
M92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG
M>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER
M.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D
M,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D
M;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92([
M"G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L
M;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE(&]R
M(&1I92!Q<5M#86XG="!W<FET92`B)'1E;7!N86UE(CH@)"%=.PIP<FEN="`D
M9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA
M;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN
M86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE
M.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?
M4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2![
M"B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6
M>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0
M?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D
M14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G
M;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T[
M"G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I
M9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@
M)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D
M:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I
M+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#
M;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D
M<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@
M(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F
M:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE
M9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D[
M"F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF
M:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*
M:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX[
M"GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ
M=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@
M*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2
M(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6
M>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,
M7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@
M("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E
M("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'
M3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N
M+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q
M(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T
M<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO
M9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN
M:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I
M;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@
M<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE
M>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!
M4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T
M*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S
M8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<
M;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE
M>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@
M)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE
M>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI
M+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*
M`'!E<FQX<VDN8P!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```
M````.@```#T````*````/0````\````]````)````#T````R````/0````(`
M```]````!0```#T````3````/0````T````]````#````#T````C````/0``
M`!$````]````)@```#T````!````/0```!<````]````"````#T````)````
M/0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````"A%0``214```$````H`P``
M`0```#,#```/````?P0```P````-$```#0```$TP```9````S'T!`!L````$
M````&@```-!]`0`<````!````/7^_V\L`0``!0```*0(```&````%`(```H`
M``"=!```"P```!`````5``````````,```#$?@$``@```.`!```4````$0``
M`!<````L#@``$0```$0-```2````Z````!,````(````&`````````#[__]O
M`0``"/K__V\0````````````````````````````````````````````````
M`````````-1]`0```````````!00```4$```%!```!00```4$```%!```!00
M```4$```%!```!00```4$```%!```!00```4$```%!```!00```4$```%!``
M`!00```4$```%!```!00```4$```%!```!00```4$```%!```!00```4$```
M%!```!00```4$```%!```!00```4$```%!```!00```4$```%!```!00```4
M$```%!```!00```4$```%!```!00```4$```%!```!00```4$```%!```!00
M```4$```%!```!00```4$```%!```!00```4$```%!````43````````````
M`$TP``````````````T0````````````````````````````````````````
M````````````@`$`_____^0P```/,0```````.DP``#I,0``]#```/LQ``#\
M,``````````Q```%,0```````)HS``!'0T,Z("A!;'!I;F4@,3`N,RXQ7V=I
M=#(P,C$P-#(T*2`Q,"XS+C$@,C`R,3`T,C0`03(```!A96%B:0`!*`````4W
M+4$`!@H'00@!"0(*!!($$P$4`14!%P,8`1H"'`$>!"(!`"YS:'-T<G1A8@`N
M:6YT97)P`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;"YD>6X`+G)E
M;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;64`+FEN
M:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S
M`"YC;VUM96YT`"Y!4DTN871T<FEB=71E<P``````````````````````````
M````````````````````````````````"P````$````"````%`$``!0!```8
M```````````````!`````````!,```#V__]O`@```"P!```L`0``Z`````,`
M````````!`````0````=````"P````(````4`@``%`(``)`&```$`````P``
M``0````0````)0````,````"````I`@``*0(``"=!``````````````!````
M`````"T````)`````@```$0-``!$#0``Z`````,`````````!`````@````V
M````"0```$(````L#@``+`X``.`!```#````$`````0````(````/P````$`
M```&````#!````P0```(```````````````"`````````#H````!````!@``
M`!00```4$```\`(`````````````!`````0```!%`````0````8````$$P``
M!!,``$@=``````````````0`````````2P````$````&````3#```$PP```(
M```````````````"`````````%$````!`````@```%0P``!4,```A#\`````
M````````!`````````!9`````0````(```#8;P``V&\```0`````````````
M``0`````````8P````X````#````S'T!`,Q]```$```````````````$````
M!````&\````/`````P```-!]`0#0?0``!```````````````!`````0```![
M````!@````,```#4?0$`U'T``/`````$``````````0````(````A`````$`
M```#````Q'X!`,1^```\`0`````````````$````!````(D````!`````P``
M``"``0``@```/```````````````!`````````"/````"`````,````\@`$`
M/(```"P0``````````````0`````````E`````$````P`````````#R````Q
M```````````````!`````0```)T````#``!P``````````!M@```,P``````
M`````````0`````````!`````P``````````````H(```*T`````````````
)``$`````````
